<?php
// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.
/*
 * Form for editing wcln_progress block instances.
 *
 * @package   block_wcln_progress
 * @copyright 2020 WCLN
 * @license   http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */
defined('MOODLE_INTERNAL') || die();
require_once($CFG->libdir . '/formslib.php');
class email_form extends moodleform {
    private function reduce_users($in, $user) {
        return $in . '<option value="'.$this->option_value($user).'">'.
               $this->option_display($user).'</option>';
    }

    private function option_display($user) {
        $userstogroups = $this->_customdata['users_to_groups'];

        if (empty($userstogroups[$user->id])) {
            $groups = wcln_progress::_s('no_section');
        } else {
            $onlynames = function($group) {
                return $group->name;
            };
            $groups = implode(',', array_map($onlynames, $userstogroups[$user->id]));
        }

        return sprintf("%s (%s)", fullname($user), $groups);
    }

    private function option_value($user) {
        $userstogroups = $this->_customdata['users_to_groups'];
        $userstoroles = $this->_customdata['users_to_roles'];
        $onlysn = function($role) {
            return $role->shortname;
        };
        if (!is_numeric($user->id)) {
            $roles = null;
        } else {
            $roles = implode(',', array_map($onlysn, $userstoroles[$user->id]));
        }

        // Everyone defaults to none.
        if (is_numeric($user->id)) {
            $roles .= ',none';
        }

        if (empty($userstogroups[$user->id])) {
            $groups = 0;
        } else {
            $onlyid = function($group) {
                return $group->id;
            };
            $groups = implode(',', array_map($onlyid, $userstogroups[$user->id]));
            $groups .= ',all';
        }
        $groups .= ',allusers';
        return sprintf("%s %s %s", $user->id, $groups, $roles);
    }

    public function definition() {
        global $CFG, $USER, $COURSE, $DB;
        $plugin = 'block_wcln_progress';
        $mform =& $this->_form;
        $mform->addElement('hidden', 'userid', $USER->id);
        $mform->setType('userid', PARAM_INT);

        $mform->addElement('hidden', 'courseid', $COURSE->id);
        $mform->setType('courseid', PARAM_INT);

        $mform->addElement('hidden', 'type', '');
        $mform->setType('type', PARAM_ALPHA);

        $mform->addElement('hidden', 'typeid', 0);
        $mform->setType('typeid', PARAM_INT);

        $links = array();
        $genurl = function($type) use ($COURSE) {
            $emailparam = array('courseid' => $COURSE->id, 'type' => $type);
            return new moodle_url('emaillog.php', $emailparam);
        };

        $context = context_course::instance($COURSE->id);

        $cansend = (
            has_capability('block/wcln_progress:cansend', $context) or
            !empty($config['allowstudents'])
        );

        if ($cansend) {
            $historylink = html_writer::link($genurl('log'), wcln_progress::_s('history'));
            $links[] =& $mform->createElement('static', 'history_link', '', $historylink);
        }

        if (has_capability('block/wcln_progress:allowalternate', $context)) {
            $alternates = $this->_customdata['alternates'];
        } else {
            $alternates = array();
        }

        if (empty($alternates)) {
            $mform->addElement('static', 'from', wcln_progress::_s('from'), $USER->email);
        } else {
            $options = array(0 => $USER->email) + $alternates;
            $mform->addElement('select', 'alternateid', wcln_progress::_s('from'), $options);
        }
        $everyonelist = wcln_progress::get_non_suspended_users($context, $COURSE->id);
        $cnt = 0;
        $defaultselect = 0;
        foreach ($everyonelist as $userlist) {
            $everyone[$userlist->id] = $userlist->firstname.' '. $userlist->lastname;
            $cnt = $cnt + 1;
            if ($cnt == 1) {
                $defaultselect = $userlist->id;
            } else {
                $defaultselect = $defaultselect. ',' .$userlist->id;
            }
        }
        if ($this->_customdata['groupsused'] == 0) {
            $mform->addElement('static', 'selectmessage', get_string('selectmessage', $plugin));
            $select = $mform->addElement('select', 'mailto', 'Enrolled users', $everyone);
            $select->setMultiple(true);
            $mform->setDefault('mailto', $defaultselect);
        } else {
            $mform->addElement('hidden', 'mailto', '0');
            $mform->setType('mailto', PARAM_INT);
        }
        if ($this->_customdata['groupsused'] == 1) {
            $params = array('courseid' => $COURSE->id);
            $grouplist = $DB->get_records('groups', $params);
            $groupnames = array();
            $firstgroup = 0;
            foreach ($grouplist as $group) {
                $groupnames[$group->id] = $group->name;
                if ($firstgroup == 0) {
                    $firstgroup = $group->id;
                }
            }
            $select = $mform->addElement('select', 'mailtogroup', get_string('coursegroups', $plugin), $groupnames);
            $select->setSelected($firstgroup);
            $select->setMultiple(true);
            $mform->addElement('hidden', 'groups', '1');
            $mform->setType('groups', PARAM_INT);
        } else {
            $mform->addElement('hidden', 'mailtogroup', '0');
            $mform->setType('mailtogroup', PARAM_INT);
            $mform->addElement('hidden', 'groups', '0');
            $mform->setType('groups', PARAM_INT);
        }
        $params21 = array($COURSE->id);
      //  $resultcontext = $DB->get_records_sql("select max(id) mid from
      //                        {context} where contextlevel <= 50 and instanceid = ? group by  contextlevel desc order by contextlevel desc", $params21);
        $resultcontext = $DB->get_records_sql("select max(id) mid from
                              {context} where contextlevel <= 50 and instanceid = ?", $params21);
          
        foreach ($resultcontext as $ctx) {
            $cid = $ctx->mid;
        }
        $params22 = array($cid);
        $teacherlist = array();
        $resultteacher = $DB->get_records_sql("select u.id, u.lastname,u.firstname from {role_assignments}
                               r,{user} u where u.id = r.userid and roleid = 3  and contextid = ?", $params22);
        if ($resultteacher) {
            $defaulteacher = 0;
            foreach ($resultteacher as $tlist) {
                $teacherlist[$tlist->id] = $tlist->firstname .' '.$tlist->lastname;
                if ($defaulteacher == 0) {
                    $defaulteacher = $tlist->id;
                }
            }
            $select = $mform->addElement('select', 'teachers', get_string('teacher', $plugin), $teacherlist);
            $select->setMultiple(true);
            $mform->setDefault('teachers', $defaulteacher);
        }
        if (!empty($CFG->block_wcln_progress_addionalemail)) {
            $mform->addElement('text', 'additional_emails', wcln_progress::_s('additional_emails'),
                    array('style' => 'width: 50%;'));
            $mform->setType('additional_emails', PARAM_TEXT);
            $mform->addRule('additional_emails', 'One or more email addresses is invalid',
                            'callback', 'block_wcln_progress_mycallback', 'client');
            $mform->addHelpButton('additional_emails', 'additional_emails', 'block_wcln_progress');
        }

        if (empty($config['messenger'])) {
            $msg = '0';
        } else {
            $msg = $config['messenger'];
        }
        if ($msg == '1') {
            $mform->addElement('text', 'subject', wcln_progress::_s('subject'));
            $mform->setType('subject', PARAM_TEXT);
            $mform->addRule('subject', null, 'required');
        } else {
            $mform->addElement('hidden', 'subject', 'N/A');
            $mform->setType('subject', PARAM_TEXT);
        }
        $mform->addElement('editor', 'message_editor', wcln_progress::_s('message'),
            null, $this->_customdata['editor_options']);
     
        $radio = array(
            $mform->createElement('radio', 'receipt', '', get_string('yes'), 1),
            $mform->createElement('radio', 'receipt', '', get_string('no'), 0)
        );

        $mform->addGroup($radio, 'receipt_action', wcln_progress::_s('receipt'), array(' '), false);
        $mform->addHelpButton('receipt_action', 'receipt', 'block_wcln_progress');
        $mform->setDefault('receipt', !empty($config['receipt']));

        $progress = array(
            $mform->createElement('radio', 'progress', '', get_string('yes'), 1),
            $mform->createElement('radio', 'progress', '', get_string('no'), 0)
        );

        $mform->addGroup($progress, 'progress_action', 'Include Progress Report', array(' '), false);
        $mform->setDefault('progress', 1);
        $cgrade = array(
            $mform->createElement('radio', 'cgrade', '', get_string('yes'), 1),
            $mform->createElement('radio', 'cgrade', '', get_string('no'), 0)
        );
        $mform->addGroup($cgrade, 'current_grade', 'Include Current Grade', array(' '), false);
        $mform->setDefault('cgrade', 1);
        $pcomp = array(
            $mform->createElement('radio', 'pcomp', '', get_string('yes'), 1),
            $mform->createElement('radio', 'pcomp', '', get_string('no'), 0)
        );
        $mform->addGroup($pcomp, 'portion_complete', 'Include Portion Complete (completion tracking must be turned on)',
                         array(' '), false);
        $mform->setDefault('pcomp', 1);
        $buttons = array();
        $buttons[] =& $mform->createElement('submit', 'send', wcln_progress::_s('send_email'));
        $buttons[] =& $mform->createElement('cancel');
        $mform->addGroup($buttons, 'buttons', wcln_progress::_s('actions'), array(' '), false);
    }
}
